@@ -1,30 +1,36 @@
 import concurrent.futures
 import functools
-import typing
-from io import BytesIO
-
-import yaml
-import shutil
+import inspect
 import json
 import os
 import queue
 import re
+import shutil
+import subprocess
 import time
+import typing
 import warnings
 from datetime import date, datetime
 from functools import lru_cache
-from io import StringIO
+from io import BytesIO, StringIO
 from itertools import chain
 from pathlib import Path
-from typing import List, Set, Union, Iterable, Tuple, Dict, Any
+from typing import List, Set, Union, Iterable, Tuple, Dict, Any, Callable
 from urllib.parse import urlparse, parse_qs, urlencode
-from tqdm.auto import tqdm
+
 import appdirs
 import numpy as np
 import pandas as pd
 import requests
+import yaml
 from requests.adapters import HTTPAdapter, Retry
+from tqdm.auto import tqdm
+from sys import executable
 
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
 from rnalysis.utils import parsing, validation, ontology, __path__
 from rnalysis import __version__
 
@@ -35,7 +41,7 @@ def get_gui_cache_dir() -> Path:
 
 
 def get_data_dir() -> Path:
-    data_dir = Path(appdirs.user_data_dir('RNAlysis', version=__version__, roaming=True))
+    data_dir = Path(appdirs.user_data_dir('RNAlysis', roaming=True))
     return data_dir
 
 
@@ -127,7 +133,7 @@ def save_gui_session(session_filename: Union[str, Path], file_names: List[str],
 
     session_data = dict(files=dict(), pipelines=dict(), metadata=dict())
     for file_name, item_name, item_type, item_property in zip(file_names, item_names, item_types, item_properties):
-        Path(get_gui_cache_dir().joinpath(file_name)).replace(session_folder.joinpath(file_name))
+        shutil.move(Path(get_gui_cache_dir().joinpath(file_name)), session_folder.joinpath(file_name))
         session_data['files'][file_name] = (item_name, item_type.__name__, item_property)
 
     for i, (pipeline_name, pipeline_file) in enumerate(zip(pipeline_names, pipeline_files)):
@@ -194,8 +200,8 @@ def load_gui_session(session_filename: Union[str, Path]):
     return items, item_names, item_types, item_properties, pipeline_names, pipeline_files
 
 
-def load_csv(filename: str, index_col: int = None, drop_columns: Union[str, List[str]] = False, squeeze=False,
-             comment: str = None):
+def load_csv(filename: Union[str, Path], index_col: int = None, drop_columns: Union[str, List[str]] = False,
+             squeeze=False, comment: str = None):
     """
     loads a csv df into a pandas dataframe.
 
@@ -275,11 +281,17 @@ class KEGGAnnotationIterator:
     REQ_MAX_ENTRIES = 10
     TAXON_TREE_CACHED_FILENAME = 'kegg_taxon_tree.json'
 
-    def __init__(self, taxon_id: int):
+    def __init__(self, taxon_id: int, pathways: Union[str, List[str], Literal['all']] = 'all'):
         self.pathway_names = {}
         self.taxon_id = taxon_id
         self.organism_code = self.get_kegg_organism_code(taxon_id)
-        self.pathway_names, self.n_annotations = self.get_pathways()
+        if pathways == 'all':
+            self.pathway_names, self.n_annotations = self.get_pathways()
+        else:
+            pathways = parsing.data_to_list(pathways)
+            assert len(pathways) > 0, f"No KEGG pathway IDs were given!"
+            self.pathway_names = {pathway: None for pathway in pathways}
+            self.n_annotations = len(self.pathway_names)
         self.pathway_annotations = None
 
     @staticmethod
@@ -851,7 +863,7 @@ def check_id_mapping_results_ready(session, url: str, job_id, polling_interval:
         r.raise_for_status()
         j = r.json()
         if "jobStatus" in j:
-            if j["jobStatus"] == "RUNNING":
+            if j["jobStatus"] in {"RUNNING", "NEW"}:
                 if verbose:
                     print(f"Retrying in {polling_interval}s")
                 time.sleep(polling_interval)
@@ -977,9 +989,9 @@ def map_gene_ids(ids: Union[str, Iterable[str]], map_from: str, map_to: str = 'U
     if id_dict_to[map_to] == id_dict_from[map_from]:
         return GeneIDTranslator()
 
-    if map_to == "UniProtKB":
+    if map_to in ["UniProtKB", "UniProtKB AC/ID"]:
         map_to = UNIPROTKB_TO
-    if map_from == "UniProtKB":
+    if map_from in ["UniProtKB", "UniProtKB AC/ID"]:
         map_from = UNIPROTKB_FROM
 
     ids = parsing.data_to_list(ids)
@@ -1022,6 +1034,7 @@ def map_gene_ids(ids: Union[str, Iterable[str]], map_from: str, map_to: str = 'U
         df = pd.DataFrame([line.split('\t') for line in results[1:]], columns=results[0].split('\t'))
         # sort annotations by decreasing annotation score, so that the most relevant annotations are at the top
         if 'Annotation' in df.columns:
+            df['Annotation'][df['Annotation'] == ''] = '0'
             df['Annotation'] = (df['Annotation']).astype(float)
             df = df.sort_values('Annotation', ascending=False)
         output_dict = {}
@@ -1246,3 +1259,167 @@ def get_gui_videos(video_paths: Tuple[str, ...]):
             content = BytesIO(req.content)
             with open(this_vid_pth, 'wb') as file:
                 file.write(content.getbuffer())
+
+
+def run_r_script(script_path: Union[str, Path], r_installation_folder: Union[str, Path, Literal['auto']] = 'auto'):
+    if r_installation_folder == 'auto':
+        prefix = "Rscript"
+    else:
+        prefix = f'{Path(r_installation_folder).as_posix()}/bin/Rscript'
+    script_path = Path(script_path).as_posix()
+
+    return_code = run_subprocess([prefix, "--help"], False, False)
+    if return_code:
+        raise FileNotFoundError(f"Failed to find R executable (return code {return_code}). "
+                                "Please make sure your R installation folder is correct. ")
+
+    return_code = run_subprocess([prefix, script_path])
+
+    assert not return_code, f"R script failed to execute (return code {return_code}). "
+
+
+def run_subprocess(args: List[str], print_stdout: bool = True, print_stderr: bool = True,
+                   log_filename: Union[str, None] = None):
+    if print_stdout or print_stderr:
+        if print_stdout and print_stderr:
+            stdout = subprocess.PIPE
+            stderr = subprocess.STDOUT
+        elif print_stdout:
+            stdout = subprocess.PIPE
+            stderr = subprocess.DEVNULL
+        else:
+            stdout = subprocess.DEVNULL
+            stderr = subprocess.PIPE
+
+        with subprocess.Popen(args, stdout=stdout, stderr=stderr) as process:
+            stream = process.stdout if print_stdout else process.stderr
+            if log_filename is not None:
+                with open(log_filename, 'w') as logfile:
+                    for line in stream:
+                        text = line.decode('utf8', errors="ignore")
+                        print(text)
+                        logfile.write(text)
+            else:
+                for line in stream:
+                    text = line.decode('utf8', errors="ignore")
+                    print(text)
+        return_code = process.returncode
+    else:
+        return_code = subprocess.run(args, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL).returncode
+
+    return return_code
+
+
+def is_rnalysis_outdated():
+    installed_version = parsing.parse_version(__version__)
+    pypi_link = 'https://pypi.python.org/pypi/RNAlysis/json'
+    try:
+        req = requests.get(pypi_link)
+    except (ConnectionError, requests.exceptions.ConnectionError, requests.exceptions.HTTPError):
+        return False
+    if req.status_code != 200:
+        return False
+    newest_version = parsing.parse_version(json.loads(req.text)['info']['version'])
+    if installed_version < newest_version:
+        return True
+    return False
+
+
+def update_rnalysis():
+    run_subprocess([executable, '-m', 'pip', 'install', '--upgrade', 'RNAlysis'])
+
+
+def map_gene_to_attr(gtf_path: Union[str, Path], attribute: str, feature_type: str, use_name: bool, use_version: bool,
+                     split_ids: bool):
+    assert feature_type in {'gene', 'transcript'}, f"Invalid feature_type: '{feature_type}'"
+
+    mapping = {}
+    with open(gtf_path, errors="ignore") as f:
+        for line in f.readlines():
+            if len(line) == 0 or line[0] == '#':
+                continue
+            line_split = line.strip().split('\t')
+            attributes = line_split[8]
+            attributes_dict = parsing.parse_gtf_attributes(attributes)
+            if attribute not in attributes_dict:
+                continue
+
+            feature_name = None
+            if feature_type == 'gene':
+                feature_id = attributes_dict['gene_id'].split(".")[0] if split_ids else attributes_dict['gene_id']
+                if use_version:
+                    feature_id += '.' + attributes_dict['gene_version']
+
+                if use_name:
+                    if 'gene_name' in attributes_dict:
+                        feature_name = attributes_dict['gene_name']
+                    elif 'name' in attributes_dict:
+                        feature_name = attributes_dict['name']
+                    else:
+                        continue
+
+            else:
+                feature_id = attributes_dict['transcript_id'].split(".")[0] if split_ids else attributes_dict[
+                    'transcript_id']
+                if use_version:
+                    feature_id += '.' + attributes_dict['transcript_version']
+
+                if use_name:
+                    if 'gene_name' in attributes_dict:
+                        feature_name = attributes_dict['transcript_name']
+                    elif 'name' in attributes_dict:
+                        feature_name = attributes_dict['name']
+                    else:
+                        continue
+
+            if feature_id in mapping:
+                continue
+            mapping[feature_name if use_name else feature_id] = attributes_dict[attribute]
+
+    return mapping
+
+
+def get_method_docstring(method: Union[str, Callable], obj: object = None) -> Tuple[str, dict]:
+    try:
+        if isinstance(method, str):
+            func = getattr(obj, method)
+        else:
+            func = method
+        raw_docstring = inspect.cleandoc(inspect.getdoc(func))
+        return parsing.parse_docstring(raw_docstring)
+    except AttributeError:
+        return '', {}
+
+
+def map_transcripts_to_genes(gtf_path: Union[str, Path], use_name: bool = False, use_version: bool = True,
+                             split_ids: bool = True):
+    mapping = {}
+    with open(gtf_path, errors="ignore") as f:
+        for line in f.readlines():
+            if len(line) == 0 or line[0] == '#':
+                continue
+            line_split = line.strip().split('\t')
+            if line_split[2] == 'transcript':
+                attributes = line_split[8]
+                attributes_dict = parsing.parse_gtf_attributes(attributes)
+                if 'transcript_id' not in attributes_dict or 'gene_id' not in attributes_dict:
+                    continue
+
+                transcript_id = attributes_dict['transcript_id'].split(".")[0] if split_ids else attributes_dict[
+                    'transcript_id']
+                gene_id = attributes_dict['gene_id'].split(".")[0] if split_ids else attributes_dict['gene_id']
+                if use_version:
+                    if 'transcript_version' in attributes_dict and 'gene_version' in attributes_dict:
+                        transcript_id += '.' + attributes_dict['transcript_version']
+                        gene_id += '.' + attributes_dict['gene_version']
+                gene_name = None
+                if use_name:
+                    if 'gene_name' not in attributes_dict:
+                        continue
+                    gene_name = attributes_dict['gene_name']
+
+                if transcript_id in mapping:
+                    continue
+
+                mapping[transcript_id] = gene_name if use_name else gene_id
+    return mapping
