@@ -1,7 +1,8 @@
-import pandas as pd
 import pytest
 from rnalysis.utils.generic import *
 import numpy as np
+import typing
+import inspect
 
 
 def test_intersection_nonempty():
@@ -71,3 +72,46 @@ def test_shift_to_baseline(data, baseline, is_df, truth):
         assert shift_to_baseline(pd.DataFrame(data), baseline).equals(pd.DataFrame(truth))
     else:
         assert np.all(shift_to_baseline(data, baseline) == truth)
+
+
+def first_test_func():
+    pass
+
+
+def second_test_func(a: str, b: bool, c):
+    pass
+
+
+def third_test_func(a: typing.List[str], b: typing.Callable, c: int = 3, d=None):
+    pass
+
+
+class TestObj:
+    def __init__(self):
+        pass
+
+    def fourth_test_func(self, a, b: None, c: float = 5.2):
+        pass
+
+
+@pytest.mark.parametrize("func,obj,truth", [
+    (first_test_func, None, {}),
+    (second_test_func, None, {'a': {'annotation': str, 'default': inspect._empty},
+                              'b': {'annotation': bool, 'default': inspect._empty},
+                              'c': {'annotation': inspect._empty, 'default': inspect._empty}}),
+    (third_test_func, None, {'a': {'annotation': typing.List[str], 'default': inspect._empty},
+                             'b': {'annotation': typing.Callable, 'default': inspect._empty},
+                             'c': {'annotation': int, 'default': 3},
+                             'd': {'annotation': inspect._empty, 'default': None}}),
+    ('fourth_test_func', TestObj(), {'a': {'annotation': inspect._empty, 'default': inspect._empty},
+                                     'b': {'annotation': None, 'default': inspect._empty},
+                                     'c': {'annotation': float, 'default': 5.2}})])
+def test_get_signature(func, obj, truth):
+    this_signature = get_method_signature(func, obj)
+    assert len(this_signature) == len(truth)
+    for key, val in truth.items():
+        assert key in this_signature
+        param = this_signature[key]
+        assert param.name == key
+        assert param.annotation == val['annotation']
+        assert param.default == val['default']
