@@ -3,6 +3,7 @@ import joblib
 from rnalysis.gui.gui_widgets import *
 import time
 from typing_extensions import Literal
+from rnalysis.utils import io
 
 LEFT_CLICK = QtCore.Qt.LeftButton
 RIGHT_CLICK = QtCore.Qt.RightButton
@@ -384,6 +385,54 @@ def test_HelpButton_desc_help(qtbot, monkeypatch):
     assert help_shown == [1]
 
 
+def test_ComparisonPicker_init(qtbot):
+    _ = widget_setup(qtbot, ComparisonPicker, io.load_csv('tests/test_files/test_design_matrix.csv', 0))
+
+
+def test_ComparisonPicker_get_value(qtbot):
+    qtbot, widget = widget_setup(qtbot, ComparisonPicker, io.load_csv('tests/test_files/test_design_matrix.csv', 0))
+    assert widget.get_value() == ('condition', 'cond1', 'cond1')
+
+    widget.factor.setCurrentText('replicate')
+    widget.numerator.setCurrentText('rep3')
+    widget.denominator.setCurrentText('rep2')
+
+    assert widget.get_value() == ('replicate', 'rep3', 'rep2')
+
+
+def test_ComparisonPickerGroup_init(qtbot):
+    _ = widget_setup(qtbot, ComparisonPickerGroup, io.load_csv('tests/test_files/test_design_matrix.csv', 0))
+
+
+def test_ComparisonPickerGroup_add_widget(qtbot):
+    qtbot, widget = widget_setup(qtbot, ComparisonPickerGroup,
+                                 io.load_csv('tests/test_files/test_design_matrix.csv', 0))
+    widget.add_comparison_widget()
+    assert len(widget.inputs) == 2
+    widget.add_comparison_widget()
+    assert len(widget.inputs) == 3
+
+
+def test_ComparisonPickerGroup_remove_widget(qtbot):
+    qtbot, widget = widget_setup(qtbot, ComparisonPickerGroup,
+                                 io.load_csv('tests/test_files/test_design_matrix.csv', 0))
+    widget.remove_comparison_widget()
+    assert len(widget.inputs) == 0
+    widget.remove_comparison_widget()
+    assert len(widget.inputs) == 0
+
+
+def test_ComparisonPickerGroup_get_comparison_values(qtbot):
+    qtbot, widget = widget_setup(qtbot, ComparisonPickerGroup,
+                                 io.load_csv('tests/test_files/test_design_matrix.csv', 0))
+    widget.add_comparison_widget()
+
+    widget.inputs[0].factor.setCurrentText('replicate')
+    widget.inputs[0].numerator.setCurrentText('rep3')
+    widget.inputs[0].denominator.setCurrentText('rep2')
+    assert widget.get_comparison_values() == [('replicate', 'rep3', 'rep2'), ('condition', 'cond1', 'cond1')]
+
+
 def test_PathLineEdit_disable(qtbot):
     qtbot, widget = widget_setup(qtbot, PathLineEdit)
 
@@ -413,6 +462,21 @@ def test_PathLineEdit_is_legal(qtbot):
     assert widget.is_legal
 
 
+@pytest.mark.parametrize('path,is_legal_expected', [
+    ('path/that/doesnt/exist', False),
+    ('tests/test_files/test_deseq.csv', False),
+    ('tests/test_files', True),
+    ('path/that/doesnt/exist.png', False)])
+def test_PathLineEdit_is_legal_dirmode(qtbot, path, is_legal_expected):
+    qtbot, widget = widget_setup(qtbot, PathLineEdit, is_file=False)
+
+    assert not widget.is_legal
+
+    widget.clear()
+    qtbot.keyClicks(widget.file_path, path)
+    assert widget.is_legal == is_legal_expected
+
+
 def test_PathLineEdit_text(qtbot):
     qtbot, widget = widget_setup(qtbot, PathLineEdit)
     widget.setText('test123')
@@ -436,6 +500,19 @@ def test_PathLineEdit_choose_file(qtbot, monkeypatch):
     assert widget.text() == pth
 
 
+def test_PathLineEdit_choose_folder(qtbot, monkeypatch):
+    pth = 'path/to/a/folder'
+
+    def mock_choose_folder(*args, **kwargs):
+        return pth
+
+    monkeypatch.setattr(QtWidgets.QFileDialog, 'getExistingDirectory', mock_choose_folder)
+    qtbot, widget = widget_setup(qtbot, PathLineEdit, is_file=False)
+    qtbot.mouseClick(widget.open_button, LEFT_CLICK)
+
+    assert widget.text() == pth
+
+
 def test_PathLineEdit_choose_file_not_chosen(qtbot, monkeypatch):
     pth = 'path/to/a/file'
 
@@ -455,7 +532,7 @@ def test_MultipleChoiceList_select_all(qtbot):
     qtbot, widget = widget_setup(qtbot, MultipleChoiceList, items)
     qtbot.mouseClick(widget.select_all_button, LEFT_CLICK)
 
-    selected_items = [item.text() for item in widget.selectedItems()]
+    selected_items = [item.text() for item in widget.get_sorted_selection()]
     assert selected_items == items
 
 
@@ -465,11 +542,11 @@ def test_MultipleChoiceList_clear_selection(qtbot):
     for item in widget.list_items:
         item.setSelected(True)
 
-    assert len(widget.selectedItems()) == len(items)
+    assert len(widget.get_sorted_selection()) == len(items)
 
     qtbot.mouseClick(widget.clear_all_button, LEFT_CLICK)
 
-    selected_items = widget.selectedItems()
+    selected_items = widget.get_sorted_selection()
     assert len(selected_items) == 0
 
 
@@ -680,7 +757,7 @@ def test_MultiChoiceListWithDelete_delete_all(qtbot, monkeypatch):
     qtbot, widget = widget_setup(qtbot, MultiChoiceListWithDelete, items)
     qtbot.mouseClick(widget.delete_all_button, LEFT_CLICK)
 
-    selected_items = [item.text() for item in widget.selectedItems()]
+    selected_items = [item.text() for item in widget.get_sorted_selection()]
     assert selected_items == []
     assert widget.items == []
 
@@ -696,7 +773,7 @@ def test_MultiChoiceListWithDelete_delete(qtbot):
     qtbot.mouseClick(widget.select_all_button, LEFT_CLICK)
     qtbot.mouseClick(widget.delete_button, LEFT_CLICK)
 
-    selected_items = [item.text() for item in widget.selectedItems()]
+    selected_items = [item.text() for item in widget.get_sorted_selection()]
     assert selected_items == []
     assert widget.items == []
 
@@ -706,7 +783,7 @@ def test_MultiChoiceListWithDelete_select_all(qtbot):
     qtbot, widget = widget_setup(qtbot, MultiChoiceListWithDelete, items)
     qtbot.mouseClick(widget.select_all_button, LEFT_CLICK)
 
-    selected_items = [item.text() for item in widget.selectedItems()]
+    selected_items = [item.text() for item in widget.get_sorted_selection()]
     assert selected_items == items
 
 
@@ -716,11 +793,11 @@ def test_MultiChoiceListWithDelete_clear_selection(qtbot):
     for item in widget.list_items:
         item.setSelected(True)
 
-    assert len(widget.selectedItems()) == len(items)
+    assert len(widget.get_sorted_selection()) == len(items)
 
     qtbot.mouseClick(widget.clear_all_button, LEFT_CLICK)
 
-    selected_items = widget.selectedItems()
+    selected_items = widget.get_sorted_selection()
     assert len(selected_items) == 0
 
 
@@ -744,6 +821,172 @@ def test_MultiChoiceListWithDelete_emit(qtbot):
     assert selection_changed == [1] * len(items) * 2 + [1]
 
 
+def test_MultiChoiceListWithReorder_up(qtbot):
+    items = ['item1', 'item2', 'item3']
+    qtbot, widget = widget_setup(qtbot, MultiChoiceListWithReorder, items)
+
+    assert widget.items == items
+
+    widget.list_items[-1].setSelected(True)
+    qtbot.mouseClick(widget.up_button, LEFT_CLICK)
+
+    selected_items = [item.text() for item in widget.get_sorted_selection()]
+    assert selected_items == ['item3']
+    assert widget.items == ['item1', 'item3', 'item2']
+
+    for i in range(3):
+        qtbot.mouseClick(widget.up_button, LEFT_CLICK)
+        selected_items = [item.text() for item in widget.get_sorted_selection()]
+        assert selected_items == ['item3']
+        assert widget.items == ['item3', 'item1', 'item2']
+
+
+def test_MultiChoiceListWithReorder_up_multi(qtbot):
+    items = ['item1', 'item2', 'item3', 'item4']
+    qtbot, widget = widget_setup(qtbot, MultiChoiceListWithReorder, items)
+
+    assert widget.items == items
+
+    widget.list_items[1].setSelected(True)
+    widget.list_items[-1].setSelected(True)
+    qtbot.mouseClick(widget.up_button, LEFT_CLICK)
+
+    selected_items = [item.text() for item in widget.get_sorted_selection()]
+    assert selected_items == ['item2', 'item4']
+    assert widget.items == ['item2', 'item1', 'item4', 'item3']
+
+    qtbot.mouseClick(widget.up_button, LEFT_CLICK)
+    selected_items = [item.text() for item in widget.get_sorted_selection()]
+    assert selected_items == ['item2', 'item4']
+    assert widget.items == ['item2', 'item4', 'item1', 'item3']
+
+
+def test_MultiChoiceListWithReorder_top(qtbot):
+    items = ['item1', 'item2', 'item3', 'item4']
+    qtbot, widget = widget_setup(qtbot, MultiChoiceListWithReorder, items)
+
+    assert widget.items == items
+
+    widget.list_items[1].setSelected(True)
+    widget.list_items[-1].setSelected(True)
+    qtbot.mouseClick(widget.top_button, LEFT_CLICK)
+
+    selected_items = [item.text() for item in widget.get_sorted_selection()]
+    assert selected_items == ['item2', 'item4']
+    assert widget.items == ['item2', 'item4', 'item1', 'item3']
+
+
+def test_MultiChoiceListWithReorder_down(qtbot):
+    items = ['item1', 'item2', 'item3']
+    qtbot, widget = widget_setup(qtbot, MultiChoiceListWithReorder, items)
+
+    assert widget.items == items
+
+    widget.list_items[0].setSelected(True)
+    qtbot.mouseClick(widget.down_button, LEFT_CLICK)
+
+    selected_items = [item.text() for item in widget.get_sorted_selection()]
+    assert selected_items == ['item1']
+    assert widget.items == ['item2', 'item1', 'item3']
+
+    for i in range(3):
+        qtbot.mouseClick(widget.down_button, LEFT_CLICK)
+        selected_items = [item.text() for item in widget.get_sorted_selection()]
+        assert selected_items == ['item1']
+        assert widget.items == ['item2', 'item3', 'item1']
+
+
+def test_MultiChoiceListWithReorder_down_multi(qtbot):
+    items = ['item1', 'item2', 'item3', 'item4']
+    qtbot, widget = widget_setup(qtbot, MultiChoiceListWithReorder, items)
+
+    assert widget.items == items
+
+    widget.list_items[0].setSelected(True)
+    widget.list_items[2].setSelected(True)
+    qtbot.mouseClick(widget.down_button, LEFT_CLICK)
+
+    selected_items = [item.text() for item in widget.get_sorted_selection()]
+    assert selected_items == ['item1', 'item3']
+    assert widget.items == ['item2', 'item1', 'item4', 'item3']
+
+    qtbot.mouseClick(widget.down_button, LEFT_CLICK)
+    selected_items = [item.text() for item in widget.get_sorted_selection()]
+    assert selected_items == ['item1', 'item3']
+    assert widget.items == ['item2', 'item4', 'item1', 'item3']
+
+
+def test_MultiChoiceListWithReorder_bottom(qtbot):
+    items = ['item1', 'item2', 'item3', 'item4']
+    qtbot, widget = widget_setup(qtbot, MultiChoiceListWithReorder, items)
+
+    assert widget.items == items
+
+    widget.list_items[0].setSelected(True)
+    widget.list_items[2].setSelected(True)
+    qtbot.mouseClick(widget.bottom_button, LEFT_CLICK)
+
+    selected_items = [item.text() for item in widget.get_sorted_selection()]
+    assert selected_items == ['item1', 'item3']
+    assert widget.items == ['item2', 'item4', 'item1', 'item3']
+
+
+def test_OrderedFileList_init(qtbot):
+    _ = widget_setup(qtbot, OrderedFileList)
+
+
+def test_OrderedFileList_add_item(qtbot):
+    pth = Path('tests/test_files/test_deseq.csv')
+    qtbot, widget = widget_setup(qtbot, OrderedFileList)
+    widget.add_item(pth)
+    assert widget.items == [pth]
+    assert len(widget.list_items) == 1
+    assert isinstance(widget.list_items[0], FileListWidgetItem)
+    assert widget.list_items[0].file_path == pth
+    assert widget.list_items[0].display_name == pth.stem
+    assert widget.list_items[0].filePath() == pth
+    assert widget.list_items[0].text() == pth.stem
+    assert widget.list.count() == 1
+
+
+@pytest.mark.parametrize("filenames", [
+    ['tests/test_files/test_deseq.csv'],
+    [],
+    ['tests/test_files/test_deseq.csv', 'tests/test_files/counted.tsv'],
+    ['tests/test_files/a.fa', 'tests/test_files/c.fa', 'tests/test_files/b.fa', 'aa.fa']
+])
+def test_OrderedFileList_add_files(qtbot, monkeypatch, filenames):
+    def mock_get_file_names(*args, **kwargs):
+        return filenames, None
+
+    monkeypatch.setattr(QtWidgets.QFileDialog, 'getOpenFileNames', mock_get_file_names)
+    qtbot, widget = widget_setup(qtbot, OrderedFileList)
+    widget.add_files()
+
+    assert widget.list.count() == len(filenames)
+    assert widget.items == filenames
+
+
+@pytest.mark.parametrize("filenames", [
+    ['tests/test_files/test_deseq.csv'],
+    [],
+    ['tests/test_files/test_deseq.csv', 'tests/test_files/counted.tsv'],
+    ['tests/test_files/a.fa', 'tests/test_files/c.fa', 'tests/test_files/b.fa', 'aa.fa']
+
+])
+def test_OrderedFileList_get_sorted_selected_names(qtbot, monkeypatch, filenames):
+    def mock_get_file_names(*args, **kwargs):
+        return filenames, None
+
+    monkeypatch.setattr(QtWidgets.QFileDialog, 'getOpenFileNames', mock_get_file_names)
+
+    qtbot, widget = widget_setup(qtbot, OrderedFileList)
+    widget.add_files()
+    res = widget.get_sorted_names()
+
+    assert res == filenames
+
+
 def test_TrueFalseBoth(qtbot):
     selection_changed = []
     qtbot, widget = widget_setup(qtbot, TrueFalseBoth)
@@ -960,7 +1203,7 @@ def test_worker(qtbot):
 
         with qtbot.waitSignal(worker.finished, timeout=4000) as blocker:
             worker.run()
-        assert blocker.args == [5 * 6 * 7, 5 + 6 + 7, 'other input']
+        assert blocker.args == [((5 * 6 * 7, 5 + 6 + 7), 'other input')]
     finally:
         try:
             worker.deleteLater()
@@ -1016,3 +1259,17 @@ def test_AltParallel_signals(qtbot):
         res = parallel(joblib.delayed(_power)(a, b) for a, b in zip(range(5), [2, 2, 2, 2, 2]))
     assert bar_updates == [1, 1, 1, 1, 1]
     assert res == [0, 1, 4, 9, 16]
+
+
+def test_TextWithCopyButton_copy_to_clipboard(qtbot, monkeypatch):
+    rich_text = '''<p>
+    Auther, F. (2001). The name of the paper. Journal.
+    <br>
+    <a href=www.google.com>doi.org/10.12345/journalName.496351</a>
+    </p>'''
+    truth = 'Auther, F. (2001). The name of the paper. Journal. \ndoi.org/10.12345/journalName.496351 '
+    qtbot, dialog = widget_setup(qtbot, TextWithCopyButton, rich_text)
+    qtbot.mouseClick(dialog.copy_button, LEFT_CLICK)
+
+    cb = QtWidgets.QApplication.clipboard().text()
+    assert cb == truth
