@@ -19,11 +19,15 @@ class DummyClassNotChild(dict):
 @pytest.mark.parametrize('obj,cls,expected', [
     ([2, 3], list, True),
     ([2, 3], dict, False),
+    ([2, 3], (dict, list), True),
+    ([2, 3], (dict, tuple), False),
     (DummyClass(), DummyClass, True),
     (DummyClass(), DummyClassChild, False),
     (DummyClassChild(), DummyClass, True),
+    (DummyClassChild(), (DummyClass, int), True),
     (DummyClassChild(), DummyClassChild, True),
-    (DummyClassNotChild(), DummyClass, False)])
+    (DummyClassNotChild(), DummyClass, False),
+    (DummyClassNotChild(), (DummyClass, DummyClassChild), False)])
 def test_isinstanceinh(obj, cls, expected):
     assert isinstanceinh(obj, cls) == expected
 
@@ -248,3 +252,13 @@ def test_validate_threshold(threshold, expected_to_pass):
 ])
 def test_is_legal_file_path(path, is_legal_truth):
     assert is_legal_file_path(path) == is_legal_truth
+
+
+@pytest.mark.parametrize('path,is_legal_truth', [
+    ('tests', True),
+    ('test_deseq.csv', False),
+    ('tests/test_files/test_count_from_folder', True),
+    ('tests/test_files/fake_dir', False)
+])
+def test_is_legal_dir_path(path, is_legal_truth):
+    assert is_legal_dir_path(path) == is_legal_truth
